@@ -20,7 +20,7 @@ import nested_diff.handlers
 
 __all__ = ['Differ', 'Iterator', 'Patcher', 'diff', 'patch']
 
-__version__ = '1.4.0'
+__version__ = '1.5.0'
 __author__ = 'Michael Samoglyadov'
 __license__ = 'Apache License, Version 2.0'
 __website__ = 'https://github.com/mr-mixas/Nested-Diff.py'
@@ -41,8 +41,7 @@ TYPE_HANDLERS = (
 
 
 class Differ:
-    """
-    Compute recursive diff for two passed objects.
+    """Compute recursive diff for two passed objects.
 
     Dicts, lists, tuples, sets and frozensets traversed recursively, other
     types compared by values. Any type diff may be customized by user-defined
@@ -102,11 +101,11 @@ class Differ:
     def __init__(
         self,
         A=True,  # noqa: N803
-        N=True,
-        O=True,  # noqa: E741
-        R=True,
-        U=True,
-        trimR=False,
+        N=True,  # noqa: N803
+        O=True,  # noqa: E741 N803
+        R=True,  # noqa: N803
+        U=True,  # noqa: N803
+        trimR=False,  # noqa: N803
         dumper=None,
         handlers=None,
     ):
