@@ -27,8 +27,15 @@ class App:
     default_ifmt = 'auto'
     default_ofmt = 'auto'
 
-    supported_ifmts = ('auto', 'ini', 'json', 'toml', 'yaml')
-    supported_ofmts = ('auto', 'ini', 'json', 'toml', 'yaml')
+    supported_ifmts = (
+        'auto',
+        'ini',
+        'json',
+        'plaintext',
+        'toml',
+        'yaml',
+    )
+    supported_ofmts = supported_ifmts
 
     version = nested_diff.__version__
 
@@ -147,11 +154,17 @@ class App:
             return IniDumper(**kwargs)
         if fmt == 'toml':
             return TomlDumper(**kwargs)
+        if fmt == 'plaintext':
+            return Dumper(**kwargs)
 
         raise RuntimeError(f'Unsupported output format: {fmt}')
 
-    @staticmethod
-    def guess_fmt(fp, default, ignore_fps=(sys.stdin, sys.stdout, sys.stderr)):
+    def guess_fmt(
+        self,
+        fp,
+        default,
+        ignore_fps=(sys.stdin, sys.stdout, sys.stderr),
+    ):
         """Guess format of a file object according it's extension."""
         if fp in ignore_fps:
             return default
@@ -161,7 +174,7 @@ class App:
         if fmt == 'yml':
             fmt = 'yaml'
 
-        return fmt if fmt else default
+        return fmt if fmt in self.supported_ifmts else default
 
     @staticmethod
     def get_loader(fmt, **kwargs):
@@ -186,6 +199,8 @@ class App:
             return IniLoader(**kwargs)
         if fmt == 'toml':
             return TomlLoader(**kwargs)
+        if fmt == 'plaintext':
+            return Loader(**kwargs)
 
         raise RuntimeError(f'Unsupported input format: {fmt}')
 
@@ -200,7 +215,7 @@ class App:
 
         """
         if self.args.ifmt == 'auto':
-            fmt = self.guess_fmt(file_, 'json')
+            fmt = self.guess_fmt(file_, 'plaintext')
         else:
             fmt = self.args.ifmt
 
@@ -248,17 +263,17 @@ class Dumper:
         self.header = header
         self.footer = footer
 
-    def encode(self, data):  # noqa U100
+    def encode(self, data):
         """Encode data.
 
         Args:
             data: Data to encode.
 
-        Raises:
-            NotImplementedError: Must be implemented in derivatives.
+        Returns:
+            Encoded data.
 
         """
-        raise NotImplementedError
+        return data
 
     @staticmethod
     def get_opts(opts):
@@ -284,17 +299,17 @@ class Dumper:
 class Loader:
     """Base class for data loaders."""
 
-    def decode(self, data):  # noqa U100
+    def decode(self, data):
         """Decode data.
 
         Args:
             data: Data to decode.
 
-        Raises:
-            NotImplementedError: Must be implemented in derivatives.
+        Returns:
+            Decoded data structure.
 
         """
-        raise NotImplementedError
+        return data
 
     @staticmethod
     def get_opts(opts):
