@@ -59,7 +59,7 @@ class TypeHandler:
 
         return equal, diff
 
-    def patch(self, patcher, target, diff):  # noqa U100
+    def patch(self, patcher, target, diff):  # noqa: ARG002
         """Patch object.
 
         Args:
@@ -82,7 +82,7 @@ class TypeHandler:
 
         raise ValueError(diff)
 
-    def iterate_diff(self, iterator, diff):  # noqa U100
+    def iterate_diff(self, iterator, diff):  # noqa: ARG002
         """Iterate over nested diff.
 
         Args:
@@ -212,6 +212,7 @@ class DictHandler(TypeHandler):
         >>> Differ(handlers=[DictHandler()], O=False, U=False).diff(a, b)
         (False, {'D': {'three': {'R': 3}, 'two': {'N': 42}}})
         >>>
+
         """
         diff = {}
         equal = True
@@ -243,10 +244,7 @@ class DictHandler(TypeHandler):
                 diff[key] = subdiff
 
         if diff:
-            if equal:
-                diff = {'U': a}
-            else:
-                diff = {'D': diff}
+            diff = {'U': a} if equal else {'D': diff}
         elif equal and differ.op_u:
             diff = {'U': a}
 
@@ -341,6 +339,7 @@ class ListHandler(TypeHandler):
         >>> Differ(handlers=[ListHandler()], O=False, U=False).diff(a, b)
         (False, {'D': [{'R': 0}, {'N': 4, 'I': 3}, {'A': 5}]})
         >>>
+
         """
         self.lcs.set_seq1(tuple(differ.dump(i) for i in a))
         self.lcs.set_seq2(tuple(differ.dump(i) for i in b))
@@ -433,7 +432,7 @@ class ListHandler(TypeHandler):
 
         return target
 
-    def iterate_diff(self, iterator, diff):  # noqa U100
+    def iterate_diff(self, iterator, diff):  # noqa: ARG002
         """Iterate over nested diff.
 
         Args:
@@ -444,7 +443,7 @@ class ListHandler(TypeHandler):
             Tuples with diff, key and subdiff for each nested diff.
 
         """
-        idx = 0  # noqa SIM113
+        idx = 0
 
         for item in diff['D']:
             try:
@@ -458,7 +457,7 @@ class ListHandler(TypeHandler):
 
     def generate_formatted_diff(self, formatter, diff, depth):
         """Generate formatted list diff."""
-        idx = 0  # noqa SIM113
+        idx = 0
 
         for subdiff in diff['D']:
             try:
@@ -509,6 +508,7 @@ class TupleHandler(ListHandler):
         >>> Differ(handlers=[TupleHandler()], O=False, U=False).diff(a, b)
         (False, {'D': ({'A': 0}, {'N': 3, 'I': 2}, {'R': 5})})
         >>>
+
         """
         equal, diff = super().diff(differ, a, b)
 
@@ -559,6 +559,7 @@ class SetHandler(TypeHandler):
         >>> Differ(handlers=[SetHandler()], U=False).diff(a, b)
         (False, {'D': [{'R': 1}, {'A': 3}], 'E': 3})
         >>>
+
         """
         diff = []
         equal = True
@@ -582,7 +583,7 @@ class SetHandler(TypeHandler):
 
         return equal, {}
 
-    def patch(self, patcher, target, diff):  # noqa U100
+    def patch(self, patcher, target, diff):  # noqa: ARG002
         """Patch set object.
 
         Args:
@@ -677,6 +678,7 @@ class TextHandler(TypeHandler):
         (False,
          {'D': [{'I': [0, 1, 0, 2]}, {'U': 'one'}, {'A': 'two'}], 'E': 5})
         >>>
+
         """
         lines_a = a.split('\n', -1)
         lines_b = b.split('\n', -1)
@@ -720,7 +722,7 @@ class TextHandler(TypeHandler):
 
         return equal, {'U': a} if differ.op_u else {}
 
-    def patch(self, patcher, target, diff):  # noqa U100
+    def patch(self, patcher, target, diff):  # noqa: ARG002
         """Patch text (multiline string).
 
         Unlike GNU patch, this algorithm does not implement any heuristics and
@@ -773,7 +775,7 @@ class TextHandler(TypeHandler):
 
                 if tag == 'I':
                     yield from formatter.generate_string(
-                        '@@ -{} +{} @@'.format(
+                        '@@ -{} +{} @@'.format(  # noqa: UP032
                             self._get_hunk_range(value[0], value[1]),
                             self._get_hunk_range(value[2], value[3]),
                         ),
